@@ -17,6 +17,7 @@
 #include <bonobo/bonobo-ui-private.h>
 #include <bonobo/bonobo-ui-main.h>
 #include <bonobo/bonobo-main.h>
+#include <bonobo/bonobo-a11y.h>
 
 #include <libgnome/gnome-init.h>
 
@@ -24,7 +25,7 @@
 
 #include <X11/Xlib.h>
 
-static int (*gdk_x_error) (Display *, XErrorEvent *);
+static int (*gdk_x_error_func) (Display *, XErrorEvent *);
 
 static int
 bonobo_x_error_handler (Display *display, XErrorEvent *error)
@@ -46,7 +47,7 @@ bonobo_x_error_handler (Display *display, XErrorEvent *error)
 	 * Otherwise, let gdk deal.
 	 */
 
-	return gdk_x_error (display, error);
+	return gdk_x_error_func (display, error);
 }
 
 /**
@@ -78,7 +79,7 @@ bonobo_setup_x_error_handler (void)
 
 	error_handler_setup = TRUE;
 
-	gdk_x_error = XSetErrorHandler (bonobo_x_error_handler);
+	gdk_x_error_func = XSetErrorHandler (bonobo_x_error_handler);
 }
 
 static gboolean bonobo_ui_inited = FALSE;
