@@ -39,6 +39,7 @@ bonobo_ui_node_new (const char *name)
 	BonoboUINode *node = g_new0 (BonoboUINode, 1);
 
 	node->name_id = g_quark_from_string (name);
+	node->ref_count = 1;
 
 	/* FIXME: we could do this idly */
 	node->attrs = g_array_new (FALSE, FALSE, sizeof (BonoboUIAttr));
@@ -84,6 +85,7 @@ bonobo_ui_node_copy (BonoboUINode *node,
 	BonoboUINode *copy;
 
 	copy = g_new0 (BonoboUINode, 1);
+	copy->ref_count = 1;
 	copy->name_id = node->name_id;
 
 	copy->content = g_strdup (node->content);
@@ -271,18 +273,37 @@ node_free_internal (BonoboUINode *node)
 {
 	BonoboUINode *l, *next;
 
+	g_return_if_fail (node->ref_count >= 0);
+
+	if (node->parent || node->next || node->prev)
+		bonobo_ui_node_unlink (node);
+
 	node_free_attrs (node);
 
 	g_free (node->content);
 
 	for (l = node->children; l; l = next) {
 		next = l->next;
-		bonobo_ui_node_free (l);
+		bonobo_ui_node_unlink (l);
+		bonobo_ui_node_unref (l);
 	}
 
 	g_free (node);
 }
 
+void
+bonobo_ui_node_unref (BonoboUINode *node)
+{
+	if (--node->ref_count <= 0) 
+		node_free_internal (node);
+}
+
+BonoboUINode *
+bonobo_ui_node_ref (BonoboUINode *node)
+{
+	node->ref_count++;
+}
+
 /**
  * bonobo_ui_node_free:
  * @node: a node.
@@ -292,12 +313,13 @@ node_free_internal (BonoboUINode *node)
 void
 bonobo_ui_node_free (BonoboUINode *node)
 {
-	if (node->parent || node->next)
-		bonobo_ui_node_unlink (node);
-	
-	node_free_internal (node);
+	if (node->ref_count > 1)
+		g_warning ("Freeing referenced node %p", node);
+
+	bonobo_ui_node_unref (node);
 }
 
+
 /**
  * bonobo_ui_node_set_data:
  * @node: the node
@@ -1101,3 +1123,40 @@ bonobo_ui_node_peek_attr (BonoboUINode *node,
 
 	return bonobo_ui_node_get_attr_by_id (node, id);
 }
+
+/**
+ * bonobo_ui_node_get_path_child:
+ * @node: parent node
+ * @name: 'name' of child node.
+ * 
+ *    Finds the child with the right name, based on
+ * the normal path traversal naming rules.
+ * 
+ * Return value: the child node or NULL.
+ **/
+BonoboUINode *
+bonobo_ui_node_get_path_child (BonoboUINode *node,
+			       const char   *name)
+{
+	BonoboUINode *l;
+	GQuark name_as_quark;
+	static GQuark name_string_id = 0;
+
+	name_as_quark = g_quark_try_string (name);
+
+	if (!name_string_id)
+		name_string_id = g_quark_from_static_string ("name");
+
+	for (l = node->children; l; l = l->next) {
+		BonoboUIAttr *a;
+
+		if ((a = get_attr (l, name_string_id, NULL)) && a->value &&
+		    !strcmp (a->value, name))
+			return l;
+
+		if (l->name_id && l->name_id == name_as_quark)
+			return l;
+	}
+
+	return NULL;
+}
